#ifndef UU_CLEAR_H
#define UU_CLEAR_H

#include "uulib/UUID.h"

void uu_clear(pUCXT, struct uu *io);

#endif
/* ex:set ts=2 sw=2 itab=spaces: */
